@@ -45,7 +45,8 @@ class SMTPChannel(object):
         except socket.error as err:
             # a race condition  may occur if the other end is closing
             # before we can get the peername
-            self.close()
+            logger.error(err)
+            self.conn.close()
             if err[0] != errno.ENOTCONN:
                 raise
             return
